// CkEmailBundle.h: interface for the CkEmailBundle class.
//
//////////////////////////////////////////////////////////////////////

#ifndef _CKEMAILBUNDLE_H
#define _CKEMAILBUNDLE_H


#pragma once

class CkStringArray;
class CkEmail;
#include "CkObject.h"

/*
    IMPORTANT: Objects returned by methods as non-const pointers must be deleted
    by the calling application. 

  */


// CLASS: CkEmailBundle
class CkEmailBundle  : public CkObject
{
    private:
	void *m_impl;
	bool m_utf8;	// If true, all input "const char *" parameters are utf-8, otherwise they are ANSI strings.

	// Don't allow assignment or copying these objects.
	CkEmailBundle(const CkEmailBundle &) { } 
	CkEmailBundle &operator=(const CkEmailBundle &) { return *this; }

    public:
	void *getImpl(void) { return m_impl; } 

	CkEmailBundle(void *impl) : m_impl(impl) { }

	CkEmailBundle();
	virtual ~CkEmailBundle();

	// BEGIN PUBLIC INTERFACE
	bool get_Utf8(void) const;
	void put_Utf8(bool b);


	CkStringArray *GetUidls(void);
	bool RemoveEmail(CkEmail *email);
	CkEmail *GetEmail(long index);
	bool AddEmail(CkEmail *email);

	long get_MessageCount(void);

	void GetXml(CkString &sbXml);
	bool SaveXml(const char *filename);
	
	bool LoadXml(const char *filename);
	bool LoadXmlString(const char *xmlStr);

	// Error log retrieval and saving (these methods are common to all Chilkat VC++ classes.)
	bool SaveLastError(const char *filename);
        void LastErrorXml(CkString &str);
        void LastErrorHtml(CkString &str);
        void LastErrorText(CkString &str);

	void SortBySubject(bool ascending);
	void SortBySender(bool ascending);
	void SortByRecipient(bool ascending);
	void SortByDate(bool ascending);


	// END PUBLIC INTERFACE

};


#endif
